@@ -58,6 +58,7 @@ from ._context import active_app, active_message_pump
 from ._event_broker import NoHandler, extract_handler_actions
 from ._path import _make_path_object_relative
 from ._wait import wait_for_idle
+from ._worker_manager import WorkerManager
 from .actions import ActionParseResult, SkipAction
 from .await_remove import AwaitRemove
 from .binding import Binding, Bindings
@@ -93,7 +94,8 @@ PLATFORM = platform.system()
 WINDOWS = PLATFORM == "Windows"
 
 # asyncio will warn against resources not being cleared
-warnings.simplefilter("always", ResourceWarning)
+if constants.DEBUG:
+    warnings.simplefilter("always", ResourceWarning)
 
 # `asyncio.get_event_loop()` is deprecated since Python 3.10:
 _ASYNCIO_GET_EVENT_LOOP_IS_DEPRECATED = sys.version_info >= (3, 10, 0)
@@ -316,6 +318,7 @@ class App(Generic[ReturnType], DOMNode):
             legacy_windows=False,
             _environ=environ,
         )
+        self._workers = WorkerManager(self)
         self.error_console = Console(markup=False, stderr=True)
         self.driver_class = driver_class or self.get_driver_class()
         self._screen_stack: list[Screen] = []
@@ -411,7 +414,6 @@ class App(Generic[ReturnType], DOMNode):
                 self.devtools = DevtoolsClient()
 
         self._loop: asyncio.AbstractEventLoop | None = None
-        self._thread_id: int = 0
         self._return_value: ReturnType | None = None
         self._exit = False
 
@@ -427,9 +429,14 @@ class App(Generic[ReturnType], DOMNode):
         self.set_class(self.dark, "-dark-mode")
         self.set_class(not self.dark, "-light-mode")
 
+    @property
+    def workers(self) -> WorkerManager:
+        """A worker manager."""
+        return self._workers
+
     @property
     def return_value(self) -> ReturnType | None:
-        """ReturnType | None: The return type of the app."""
+        """The return type of the app."""
         return self._return_value
 
     @property
@@ -508,7 +515,7 @@ class App(Generic[ReturnType], DOMNode):
 
     @property
     def screen_stack(self) -> list[Screen]:
-        """list[Screen]: A *copy* of the screen stack."""
+        """A *copy* of the screen stack."""
         return self._screen_stack.copy()
 
     def exit(
@@ -528,7 +535,7 @@ class App(Generic[ReturnType], DOMNode):
 
     @property
     def focused(self) -> Widget | None:
-        """Widget | None: the widget that is focused on the currently active screen."""
+        """The widget that is focused on the currently active screen."""
         return self.screen.focused
 
     @property
@@ -654,7 +661,7 @@ class App(Generic[ReturnType], DOMNode):
 
     @property
     def size(self) -> Size:
-        """Size: The size of the terminal."""
+        """The size of the terminal."""
         if self._driver is not None and self._driver._size is not None:
             width, height = self._driver._size
         else:
@@ -663,7 +670,7 @@ class App(Generic[ReturnType], DOMNode):
 
     @property
     def log(self) -> Logger:
-        """Logger: The logger object."""
+        """The logger object."""
         return self._logger
 
     def _log(
@@ -933,6 +940,8 @@ class App(Generic[ReturnType], DOMNode):
             app_ready_event.set()
 
         async def run_app(app) -> None:
+            app._loop = asyncio.get_running_loop()
+            app._thread_id = threading.get_ident()
             await app._process_messages(
                 ready_callback=on_app_ready,
                 headless=headless,
@@ -1620,6 +1629,7 @@ class App(Generic[ReturnType], DOMNode):
             except asyncio.CancelledError:
                 pass
             finally:
+                self.workers.cancel_all()
                 self._running = False
                 try:
                     await self.animator.stop()
