@@ -166,5 +166,5 @@ class Header(Widget):
         def set_sub_title(sub_title: str) -> None:
             self.query_one(HeaderTitle).sub_text = sub_title
 
-        self.watch(self.app, "title", set_title)  # type: ignore[arg-type]
-        self.watch(self.app, "sub_title", set_sub_title)  # type: ignore[arg-type]
+        self.watch(self.app, "title", set_title)
+        self.watch(self.app, "sub_title", set_sub_title)
